@@ -184,6 +184,10 @@ go_palette_class_init (GOPaletteClass *class)
 			      G_TYPE_NONE, 0);
 
 	g_type_class_add_private (object_class, sizeof (GOPalettePrivate));
+
+#ifdef HAVE_GTK_WIDGET_CLASS_SET_CSS_NAME
+	gtk_widget_class_set_css_name (widget_class, "palette");
+#endif
 }
 
 static void
@@ -283,6 +287,7 @@ cb_custom_activate (GtkWidget *item, GOPalette *palette)
  * @swatch_width: swatch width as multiple of swatch height
  * @n_columns: number of columns for displaying palette items
  * @swatch_render: (scope notified): a user function used for swatch rendering
+ * @get_tooltip: (scope notified): a user function for tooltips.
  * @data: user data for use by swatch render function
  * @destroy: (scope async): a function to destroy user data on widget finalization
  *
