@@ -85,7 +85,7 @@ static void
 go_pixbuf_save (GOImage *image, GsfXMLOut *output)
 {
 	GOPixbuf *pixbuf;
-	g_return_if_fail (GO_IS_PIXBUF (image));
+	g_return_if_fail (GO_IS_PIXBUF (image) && image->data != NULL);
 	pixbuf = GO_PIXBUF (image);
 	if (pixbuf->type == NULL) {
 		pixbuf->type = g_strdup ("png");
@@ -339,6 +339,7 @@ go_pixbuf_finalize (GObject *obj)
 		g_object_unref (pixbuf->pixbuf);
 	if (pixbuf->surface)
 		cairo_surface_destroy (pixbuf->surface);
+	g_free (pixbuf->cairo_pixels);
 	g_free (pixbuf->type);
 	(parent_klass->finalize) (obj);
 }
